=========
pref-vote
=========


Add a short description here!


Description
===========

A longer description of your project goes here...


Note
====

This project has been set up using PyScaffold 2.5.8. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
